
#ifndef _C1_an1_
#define _C1_an1_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1_5(EIF_REFERENCE);
extern EIF_BOOLEAN F1_7(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_8(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F1_10(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_14(EIF_REFERENCE);
extern void F1_15(EIF_REFERENCE, EIF_REFERENCE);
extern void F1_16(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F1_20(EIF_REFERENCE);
extern void F1_23(EIF_REFERENCE);
static EIF_REFERENCE F1_24_body(EIF_REFERENCE);
extern EIF_REFERENCE F1_24(EIF_REFERENCE);
extern void F1_29(EIF_REFERENCE);
extern void F1_30(EIF_REFERENCE);
extern void F1_31(EIF_REFERENCE);
extern EIF_POINTER F1_33(EIF_REFERENCE);
extern void EIF_Minit1(void);
extern void F28_417(EIF_REFERENCE);
extern void F915_6057(EIF_REFERENCE, EIF_REFERENCE);
extern void F913_5944(EIF_REFERENCE, EIF_REFERENCE);
extern void F122_1523(EIF_REFERENCE, EIF_REFERENCE);
extern EIF_REFERENCE F906_5673(EIF_REFERENCE);
extern char *(*R3470[])();
extern char *(*R11[])();
extern char *(*R2981[])();

#ifdef __cplusplus
}
#endif

#endif
